@@ -75,6 +75,14 @@ test_that("Can add to an existing workbook", {
 })
 
 
+test_that("Can add to an existing worksheet", {
+  hx <- huxtable(a = 1:3, b = 4:6)
+  wb <- openxlsx::createWorkbook()
+  wb <- as_Workbook(hx, Workbook = wb, sheet = "sheet1")
+  expect_silent(as_Workbook(hx, Workbook = wb, sheet = "sheet1", start_row = 6))
+})
+
+
 test_that("Can write with offset rows and columns", {
   hx <- huxtable(a = 1:3, b = 4:6)
   expect_silent(wb <- as_Workbook(hx, start_col = 3, start_row = 2))
